@@ -7,6 +7,7 @@ import tarfile
 from collections import defaultdict
 from datetime import datetime
 from itertools import chain
+from operator import attrgetter
 from tempfile import TemporaryDirectory
 from urllib.parse import urlparse
 
@@ -189,6 +190,9 @@ class _RemovalRepo(UnconfiguredTree):
             f.write('old-repo\n')
         super().__init__(repo_dir)
 
+    def cleanup(self):
+        self.__tmpdir.cleanup()
+
     def __call__(self, pkgs):
         """Update the repo with a given sequence of packages."""
         self._populate(pkgs)
@@ -201,10 +205,11 @@ class _RemovalRepo(UnconfiguredTree):
 
     def _populate(self, pkgs):
         """Populate the repo with a given sequence of historical packages."""
-        pkg = pkgs[0]
+        pkg = min(pkgs, key=attrgetter('time'))
         paths = [pjoin(pkg.category, pkg.package)]
-        if os.path.exists(pjoin(self.__parent_repo.location, 'eclass')):
-            paths.append('eclass')
+        for subdir in ('eclass', 'profiles'):
+            if os.path.exists(pjoin(self.__parent_repo.location, subdir)):
+                paths.append(subdir)
         old_files = subprocess.Popen(
             ['git', 'archive', f'{pkg.commit}~1'] + paths,
             stdout=subprocess.PIPE, stderr=subprocess.PIPE,
@@ -235,16 +240,23 @@ class GitPkgCommitsCheck(GentooRepoCheck, GitCommitsCheck):
         self.repo = self.options.target_repo
         self.valid_arches = self.options.target_repo.known_arches
         self._git_addon = git_addon
+        self._cleanup = []
+
+    def cleanup(self):
+        for repo in self._cleanup:
+            repo.cleanup()
 
     @klass.jit_attr
     def removal_repo(self):
         """Create a repository of packages removed from git."""
-        return _RemovalRepo(self.repo)
+        self._cleanup.append(repo := _RemovalRepo(self.repo))
+        return repo
 
     @klass.jit_attr
     def modified_repo(self):
         """Create a repository of old packages newly modified in git."""
-        return _RemovalRepo(self.repo)
+        self._cleanup.append(repo := _RemovalRepo(self.repo))
+        return repo
 
     @klass.jit_attr
     def added_repo(self):
